@@ -1,3 +1,5 @@
+// kdelibs4.js of Serbian KDE translation
+
 // ------------------------------
 // Property getter object contains the following data attributes:
 // - callname: the name of the getter call as exposed to PO files
@@ -497,61 +499,6 @@ function decline_person_name_nf (gcase, fullname)
 Ts.setcall("именски/ф", decline_person_name_nf);
 // "You have invited $[callname case %1] to the party."
 
-// ------------------------------
-// Load property map on demand, not to burden app startup time.
-// The first argument is the map name (without extenstion).
-// The second argument controls whether the function returns empty string
-// (if true-valued), or signals fallback (if false-valued).
-// Use this function as a PO call in a message certainly encountered prior
-// to any messages requiring the maps. *Do not* call this function directly in
-// another scripting module, as the relative path to map file will be wrong.
-var pmap_loaded = {};
-function load_pmap (pmap, return_empty)
-{
-    if (!pmap_loaded[pmap])
-    {
-        // First indicate that the map is prepared, then load.
-        // So that when the map file does not exists or is malformed
-        // and throws, there will be no more attempts to load.
-        pmap_loaded[pmap] = true;
-        Ts.loadProps(pmap);
-    }
-    if (return_empty)
-        return "";
-    else
-        throw Ts.fallback();
-}
-
-// Setup the calls for maps available on demand, such that:
-// - the default, load the map and signal fallback
-// - with /п suffix, load the map and return empty string
-var call_suffix_to_pmap = {
-    // call_suffix : map_name
-    // suffix in accusative (appened to "prepare-" for call name).
-    "програме" : "apps",
-    "језике" : "languages",
-    "државе" : "countries",
-    "фонтове" : "fonts",
-    "места" : "places",
-    "доприносиоце" : "contributors",
-};
-for (suffix in call_suffix_to_pmap) {
-    Ts.setcall("спреми-" + suffix,
-        function () { return load_pmap(this.pmap, false) },
-        {"pmap" : call_suffix_to_pmap[suffix]});
-    // "$[спреми-<мапу>]"
-
-    Ts.setcall("спреми-" + suffix + "/п",
-        function () { return load_pmap(this.pmap, true) },
-        {"pmap" : call_suffix_to_pmap[suffix]});
-    // "$[спреми-<мапу>/п]"
-}
-// Kill loaders for fonts pmap in case the user requested so.
-if (!Ts.getConfBool("translate-fonts", true)) {
-    Ts.setcall("спреми-фонтове", function () { return Ts.fallback() });
-    Ts.setcall("спреми-фонтове/п", function () { return "" });
-}
-
 // ------------------------------
 // Match style attributes to gender of the font family name,
 // for the requested grammatical case.
@@ -581,7 +528,45 @@ function match_style_to_font (compstyle, gcase)
 Ts.setcall("стил-према-фонту", match_style_to_font);
 
 // ------------------------------
-// Property maps needed for all apps.
-Ts.loadProps("apps");
-Ts.loadProps("places");
-Ts.loadProps("calendar");
+// Pick a phrase depending on a dynamic context field.
+// Input is the keyword of the context field, followed by pairs of
+// regex matcher on context value and corresponding phrase,
+// and optionally followed by default phrase in case the value does not match.
+// If the value does not match and default phrase is not given,
+// fallback is signaled.
+// If requested dynamic context field does not exist, fallback is signaled.
+function select_by_context (/* ctxt_key,
+                               valrx_1, phrase_1, ..., valrx_N, phrase_N
+                               [, default_phrase]*/)
+{
+    if (arguments.length < 1)
+        throw Error("Selector by context takes at least the context keyword.");
+
+    var ctxtkey = arguments[0];
+    var ctxtval = Ts.dynctxt(ctxtkey);
+
+    var phrase;
+    for (var i = 1; i < arguments.length; i += 2) {
+        if (ctxtval.match(RegExp(arguments[i]))) {
+            phrase = arguments[i + 1];
+            break;
+        }
+    }
+    if (phrase == undefined) {
+        if (arguments.length % 2 == 0) {
+            phrase = arguments[arguments.length - 1];
+        } else {
+            throw Ts.fallback();
+        }
+    }
+
+    return phrase;
+}
+Ts.setcall("по-контексту", select_by_context);
+
+// ------------------------------
+// Load property maps.
+Ts.loadProps("trapnakron");
+// // Do not load fonts pmap if the user requested so.
+// if (!Ts.getConfBool("translate-fonts", true)) {
+// }
